<?php

namespace Bluesquare\Connect;

use Bluesquare\Connect\Commands\Sync;
use Bluesquare\Connect\View\Components\Button;
use Illuminate\Support\ServiceProvider;

class ConnectServiceProvider extends ServiceProvider
{
    /**
     * Register any application services.
     *
     * @return void
     */
    public function register()
    {
        // Config

        $this->mergeConfigFrom(
            __DIR__ . '/../config/bconnect.php',
            'bconnect'
        );

        // Singletons

        $this->app->singleton(Connect::class, function ($app) {
            return new Connect($app);
        });
    }

    /**
     * Bootstrap any application services.
     *
     * @return void
     */
    public function boot()
    {
        // Config

        $this->publishes([
            __DIR__ . '/../config/bconnect.php' => config_path('bconnect.php')
        ]);

        // Translations

        $this->loadTranslationsFrom(__DIR__.'/../resources/translations', 'connect');

        // Views

        $this->loadViewsFrom(__DIR__.'/../resources/views/connect', 'connect');

        $this->publishes([
            __DIR__.'/../resources/views/connect' => resource_path('views/vendor/connect'),
        ]);

        $this->loadViewComponentsAs('connect', [
            Button::class
        ]);

        // Commands

        if ($this->app->runningInConsole()) {
            $this->commands([
                Sync::class
            ]);
        }
    }
}
